@@ -1,11 +1,9 @@
 import os
 import inspect
-import jsonschema
 from jinja2 import Template
 from .exception import LivemarkException
 
 
-# TODO: implement process_config hook?
 class Plugin:
     priority = 0
     profile = {}
@@ -13,13 +11,6 @@ class Plugin:
     def __init__(self, document):
         self.__document = document
 
-        # Normalize/validate config
-        config = document.config.setdefault(self.name, {})
-        if config is True:
-            document.config[self.name] = {"value": config}
-        if config and self.profile:
-            jsonschema.validate(config, self.profile)
-
     @property
     def name(self):
         return self.__class__.__name__.replace("Plugin", "").lower()
@@ -34,6 +25,9 @@ class Plugin:
 
     # Actions
 
+    def process_config(self, config):
+        pass
+
     def process_document(self, document):
         pass
 
