@@ -6,7 +6,7 @@ class LinksPlugin(Plugin):
     profile = {
         "type": "object",
         "properties": {
-            "list": {
+            "items": {
                 "type": "array",
                 "items": {
                     "type": "object",
@@ -20,23 +20,26 @@ class LinksPlugin(Plugin):
         },
     }
 
+    def process_config(self, config):
+        self.config.setdefault("items", self.config.pop("self", []))
+
     def process_markup(self, markup):
         github = self.get_plugin("github")
         if not self.config:
             return
 
         # Prepare context
-        list = self.config.get("list", []).copy()
+        items = self.config["items"].copy()
         if github.config:
-            list.append({"name": "Report", "path": github.config["report_url"]})
-        list.append({"name": "Print", "hook": "window.print();return false;"})
+            items.append({"name": "Report", "path": github.config["report_url"]})
+        items.append({"name": "Print", "hook": "window.print();return false;"})
         if github.config:
-            list.append({"name": "Edit", "path": github.config["edit_url"]})
+            items.append({"name": "Edit", "path": github.config["edit_url"]})
 
         # Update markup
         markup.add_style("style.css")
         markup.add_markup(
             "markup.html",
             target="#livemark-right",
-            list=list,
+            items=items,
         )
